<?php
/*
Plugin Name: Countdown
Plugin URI: http://www.asymptomatic.net/wp-hacks
Description: Adds template tags to count down to a specified date.  Edit your dates <a href="templates.php?file=wp-content%2Fplugins%2Fdates.txt&submit=Edit+file+%C2%BB">here</a>.  (Works for me, maybe not for you!)
Version: 1.1
Author: Owen Winkler
Author URI: http://www.asymptomatic.net
*/
/*
Countdown - Adds template tags to count down to a specified date

This code is licensed under the MIT License.
http://www.opensource.org/licenses/mit-license.php
Copyright (c) 2004 Owen Winkler

Permission is hereby granted, free of charge, to any person
obtaining a copy of this software and associated
documentation files (the "Software"), to deal in the
Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to
do so, subject to the following conditions:

The above copyright notice and this permission notice shall
be included in all copies or substantial portions of the
Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/


function dtr_monthtonum($m)
{
	switch(strtolower(substr($m, 0, 3)))
	{
	case 'jan': return 1;
	case 'fev': return 2;
	case 'mar': return 3;
	case 'avr': return 4;
	case 'mai': return 5;
	case 'jun': return 6;
	case 'jul': return 7;
	case 'aou': return 8;
	case 'sep': return 9;
	case 'oct': return 10;
	case 'nov': return 11;
	case 'dec': return 12;
	}
	return 0;
}

function dtr_weekdaytonum($m)
{
	switch(strtolower(substr($m, 0, 3)))
	{
	case 'lun': return 1;
	case 'mar': return 2;
	case 'mer': return 3;
	case 'jeu': return 4;
	case 'ven': return 5;
	case 'sam': return 6;
	case 'dim': return 0;
	}
	return 0;
}

function dtr_xsttonum($x)
{
	switch(substr($x, 0, 1))
	{
	case '1': return 1;
	case '2': return 2;
	case '3': return 3;
	case '4': return 4;
	case '5': return 5;
	case 'l': return 6;
	}
}

function dtr_xst_weekday($index, $weekday, $month)
{
	$now = getdate();
	$year = $now['year'] + (($month<$now['mon'])? 1 : 0);

	$day = 1;
	$firstday = intval(date('w', mktime(0,0,0,$month, $day, $year)));

	$day += $weekday - $firstday;
	if($day <= 0) $day += 7;
	$index --;
	while($index > 0)
	{
		$day += 7;
		$index --;
		if(!checkdate($month, $day + 7, $year)) break;
	}
	return mktime(0, 0, 0, $month, $day, $year);
}

function dates_to_remember($showonly = -1, $timefrom = null, $startswith = '<li>', $endswith = '</li>', $paststartswith = '<li class="pastevent">', $pastendswith = '</li>')
{
	$datefile = implode('', file(dirname(__FILE__) . '/dates.txt'));
	$dates = explode("\n", $datefile);
	$dtr = array();
	$dtrflags = array();

	if($timefrom == null) $timefrom = strtotime(date('Y-m-d', time() + (get_settings('gmt_offset') * 3600)));

	foreach($dates as $entry)
	{
		if(trim($entry) == '') continue;
		$flags = array();
		if(preg_match('/every ?(2nd|other|3rd|4th)? week (starting|from) ([0-9]{4}-[0-9]{2}-[0-9]{2})( until ([0-9]{4}-[0-9]{2}-[0-9]{2}))?[\\s]+(.*)/i', $entry, $matches))
		{
			switch($matches[1])
			{
			case '2nd':
			case 'other': $inc = 14; break;
			case '3rd': $inc = 21; break;
			case '4th': $inc = 28; break;
			default: $inc = 7;
			}
			$date_info = getdate(strtotime($matches[3]));
			$absday = ceil($date_info[0] / 86400);
			$today_info = getdate(time());
			$todayday = ceil($today_info[0] / 86400);
			if($absday == $todayday)
			{
				$eventtime = $absday * 86400;			
			}
			else
			{
				$chunk = ceil(($todayday - $absday) / $inc);
				$absday = $absday + ($chunk * $inc);
				$eventtime = $absday * 86400;			
			}
			if($matches[5] != '')
			{
				$limit = strtotime($matches[5]);
				if($timefrom - 86400 > $limit) $eventtime = $limit;
			}
			$eventname = $matches[6];
		}
		else if(preg_match('/([0-9]{4}-[0-9]{2}-[0-9]{2})[\\s]+(.*)/i', $entry, $matches))
		{
			$eventtime = strtotime($matches[1]);
			$eventname = $matches[2];
		}
		else if(preg_match('/([0-9]{2}-[0-9]{2})[\\s]+(.*)/i', $entry, $matches))
		{
			$eventtime = strtotime(date('Y', time() + (get_settings('gmt_offset') * 3600)).'-'.$matches[1]);
			if($timefrom > $eventtime) $eventtime = strtotime(date('Y', time() + 31536000).'-'.$matches[1]);
			$eventname = $matches[2];
		}
		else if(preg_match('/(1st|2nd|3rd|4th|5th|last)[\\s]+(lun(?:di)?|mar(?:di)?|mer(?:credi)?|jeu(?:di)?|ven(?:dredi)?|sam(?:edi)?|dim(?:anche)?)[\\s]+(jan(?:vier)?|fev(?:rier)?|mar(?:s)?|avr(?:il)?|mai|jun(?:e)?|jul(?:y)?|aou(?:t)?|sep(?:tembre)?|oct(?:obre)?|nov(?:embre)?|dec(?:embre)?|all)(.*)/i', $entry, $matches))
		{
			$eventname = $matches[4];
			$xst = dtr_xsttonum($matches[1]);
			$day = dtr_weekdaytonum($matches[2]);
			if($matches[3] == 'all')
			{
				$month = dtr_monthtonum(date('M', $timefrom));
				$eventtime = dtr_xst_weekday($xst, $day, $month);
				if($eventtime < $timefrom)
				{
					$zero_hour = getdate($timefrom);
					$month = dtr_monthtonum(date('M', mktime(0,0,0, ($zero_hour['mon'] % 12) + 1, 1, $_zero_hour['year'])));
					$eventtime = dtr_xst_weekday($xst, $day, $month);
				}
			}
			else
			{
				$month = dtr_monthtonum($matches[3]);
				$eventtime = dtr_xst_weekday($xst, $day, $month);
			}
		}
		else
		{
			continue;
		}

		$eventname = preg_replace('/%(.*?)%/e', '($flags[]="\\1")?"":""', $eventname);

		if($timefrom <= $eventtime)
		{
			while(isset($dtr[$eventtime]) && $dtr[$eventtime] != $eventname) $eventtime ++;
			$dtr[$eventtime] = $eventname;
			$dtrflags[$eventtime] = $flags;
		}
	}
	ksort($dtr);

	foreach($dtr as $eventtime => $event)
	{
		$do_daystil = !in_array('nocountdown', $dtrflags[$eventtime]);
		countdown_days($event, date('Y-m-d', $eventtime), $startswith, $endswith, $paststartswith, $pastendswith, $do_daystil);
		$showonly --;
		if($showonly == 0) break;
	}
}

//
//ajout fonction  kongasiou dean
//		
function getJour($day) {
return $jour[$day];
}
function getMois($month){
return $mois[$month];
}
//
//fin ajout fonction  kongasiou dean
//	

function countdown_days($event, $date, $startswith = '', $endswith = '', $paststartswith = '', $pastendswith = '', $do_daystil = true) {
	$until = intval((strtotime($date) - strtotime(date('Y-m-d', time() + (get_settings('gmt_offset') * 3600)))) / 86400);
	//if($until >= 0) {
 		echo $startswith;
//
//ajout   kongasiou dean
//			
$jour["Monday"] = "Lundi";
$jour["Tuesday"] = "Mardi";
$jour["Wednesday"] = "Mercredi";
$jour["Thursday"] = "Jeudi";
$jour["Friday"] = "Vendredi";
$jour["Saturday"] = "Samedi";
$jour["Sunday"] = "Dimanche";	

$mois["January"] = "Janvier";
$mois["February"] = "Fevrier";
$mois["March"] = "Mars";
$mois["April"] = "Avril";
$mois["May"] = "Mai";
$mois["June"] = "Juin";
$mois["July"] = "Juillet";
$mois["August"] = "Aot";
$mois["September"] = "Septembre";
$mois["October"] = "Octobre";
$mois["November"] = "Novembre";
$mois["December"] = "Decembre";	

//modifs kongasiou dean		
$month = date('F', strtotime($date));
$day = date('l', strtotime($date));
getJour($day);
getMois($month);
//echo $jour[$day];
echo date('j', strtotime($date));  
echo " ".$mois[$month]; 
//echo date('Y', strtotime($date)); 
//		$date_format = 'd m Y';
//		echo date($date_format, strtotime($date));
//fin modifs kongasiou dean	

		echo " - {$event}";
		if($do_daystil)
		{
			echo " (";
			switch($until)
			{
			case 0: echo 'Aujourd&acute;hui'; break;
			case 1: echo 'J - 1'; break;
			default: echo "J - {$until}"; break;
			}
			echo ")";
		}
		echo $endswith;
	/*}
	else
	{
 		echo $paststartswith;
		$date_format = 'j M.';
		echo date($date_format, strtotime($date));
		echo " - {$event}";
		if($do_daystil)
		{
			echo " (";
			switch(abs($until))
			{
			case 1: echo 'J + 1'; break;
			default: echo "J + {$until}"; break;
			}
			echo ")";
		}
		echo $pastendswith;
	}*/
}



?>